[llvm-commits] CVS: llvm/include/llvm/CodeGen/LiveVariables.h

Evan Cheng evan.cheng at apple.com
Sat Feb 17 03:07:25 PST 2007



Changes in directory llvm/include/llvm/CodeGen:

LiveVariables.h updated: 1.32 -> 1.33
---
Log message:

Allow LiveVariables to track liveness of more registers.

---
Diffs of the changes:  (+5 -4)

 LiveVariables.h |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)


Index: llvm/include/llvm/CodeGen/LiveVariables.h
diff -u llvm/include/llvm/CodeGen/LiveVariables.h:1.32 llvm/include/llvm/CodeGen/LiveVariables.h:1.33
--- llvm/include/llvm/CodeGen/LiveVariables.h:1.32	Wed Feb 14 23:57:14 2007
+++ llvm/include/llvm/CodeGen/LiveVariables.h	Sat Feb 17 05:07:08 2007
@@ -36,6 +36,7 @@
 namespace llvm {
 
 class MRegisterInfo;
+class BitVector;
 
 class LiveVariables : public MachineFunctionPass {
 public:
@@ -108,11 +109,11 @@
   ///
   std::vector<VarInfo> VirtRegInfo;
 
   /// AllocatablePhysicalRegisters - This vector keeps track of which registers
   /// are actually register allocatable by the target machine.  We can not track
   /// liveness for values that are not in this set.
   ///
-  BitVector AllocatablePhysicalRegisters;
+  BitVector ReservedRegisters;
 
 private:   // Intermediate data structures
   const MRegisterInfo *RegInfo;
@@ -108,11 +109,11 @@
   std::vector<VarInfo> VirtRegInfo;
 
-  /// AllocatablePhysicalRegisters - This vector keeps track of which registers
-  /// are actually register allocatable by the target machine.  We can not track
-  /// liveness for values that are not in this set.
+  /// ReservedRegisters - This vector keeps track of which registers
+  /// are reserved register which are not allocatable by the target machine.
+  /// We can not track liveness for values that are in this set.
   ///






More information about the llvm-commits mailing list